# О библиотеке

`YaTracker` представляет собой асинхронный клиент на `python` для удобной работы с API Яндекс.Трекера.

## Предостережение

Данная библиотека работает **только** с асинхронными приложениями,
и требует наличия базовых навыков работы с python.
